==> jc-1.4.0.tar.gz: javax/swing/plaf/basic/BasicBorders__24FieldBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$FieldBorder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 6c96f004fa4f6930 javax_swing_plaf_basic_BasicBorders__24FieldBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24FieldBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24FieldBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$_init$a2eeceddaaddcabf(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *);

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *);
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
extern void _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *);
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *);
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24FieldBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs {
	struct _jc_java_awt_Color$object	*shadow;
	struct _jc_java_awt_Color$object	*darkShadow;
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*lightHighlight;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24FieldBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24FieldBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24FieldBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24FieldBorder_H_ */

==> jc-1.4.5.tar.gz: javax/swing/plaf/basic/BasicBorders__24FieldBorder.h <==
// public class javax.swing.plaf.basic.BasicBorders$FieldBorder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 564dabb34efb5ce6 javax_swing_border_AbstractBorder
// @dep_class 6c96f004fa4f6930 javax_swing_plaf_basic_BasicBorders__24FieldBorder

// header file dependencies
// @dep_header javax_swing_border_AbstractBorder

#include "javax/swing/border/AbstractBorder.h"

#ifndef _JC_javax_swing_plaf_basic_BasicBorders__24FieldBorder_H_
#define _JC_javax_swing_plaf_basic_BasicBorders__24FieldBorder_H_

// Forward structure declarations
struct _jc_java_awt_Color$object;
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_awt_Insets$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs;
typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object;

typedef struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable;
typedef const struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$fields_struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$_init$a2eeceddaaddcabf(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *, struct _jc_java_awt_Color$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$getBorderInsets$f3b72649b74c5030(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
extern struct _jc_java_awt_Insets$object *_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$getBorderInsets$8c7185b35170132d(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method$paintBorder$4a79b2eae89db578(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method_info$getBorderInsets$f3b72649b74c5030;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method_info$getBorderInsets$8c7185b35170132d;
extern _jc_method _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$method_info$paintBorder$4a79b2eae89db578;

// Virtual methods structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods {
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$f3b72649b74c5030)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;
	struct _jc_java_awt_Insets$object	*(*getBorderInsets$8c7185b35170132d)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Insets$object *) _JC_JCNI_ATTR;
	void	(*paintBorder$4a79b2eae89db578)(_jc_env *, struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_border_AbstractBorder$vmethods	javax_swing_border_AbstractBorder;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vmethods	javax_swing_plaf_basic_BasicBorders__24FieldBorder;
};

// Vtype
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs {
	struct _jc_java_awt_Color$object	*shadow;
	struct _jc_java_awt_Color$object	*darkShadow;
	struct _jc_java_awt_Color$object	*highlight;
	struct _jc_java_awt_Color$object	*lightHighlight;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs {
    _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_refs	javax_swing_plaf_basic_BasicBorders__24FieldBorder;
    _jc_javax_swing_border_AbstractBorder$sub_refs	javax_swing_border_AbstractBorder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_border_AbstractBorder$sub_nonrefs	javax_swing_border_AbstractBorder;
    _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$sub_nonrefs	javax_swing_plaf_basic_BasicBorders__24FieldBorder;
};

// Object instance structure
struct _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$object {
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype	*vtype;
	_jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$vtype _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_basic_BasicBorders__24FieldBorder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_basic_BasicBorders__24FieldBorder$class_object;

#endif	/* _JC_javax_swing_plaf_basic_BasicBorders__24FieldBorder_H_ */
